Database helpers
================


.. module:: sqlalchemy_utils.functions


analyze
-------

.. autofunction:: analyze


database_exists
---------------

.. autofunction:: database_exists


create_database
---------------

.. autofunction:: create_database


drop_database
-------------

.. autofunction:: drop_database


has_index
---------

.. autofunction:: has_index


has_unique_index
----------------

.. autofunction:: has_unique_index


json_sql
--------

.. autofunction:: json_sql


render_expression
-----------------

.. autofunction:: render_expression


render_statement
----------------

.. autofunction:: render_statement
